About Us
========

HoloViews is an `open-source <https://github.com/holoviz/holoviews/blob/master/LICENSE.txt>`_ Python library designed to make data analysis and visualization seamless and simple.  With HoloViews, you can usually express what you want to do in very few lines of code, letting you focus on what you are trying to explore and convey, not on the process of plotting.

HoloViews is part of the `HoloViz <https://holoviz.org>`_ family of tools. The `holoviz.org <https://holoviz.org>`_ website shows how to use HoloViews together with other libraries to solve complex problems, with detailed tutorials and examples. You can see a variety of projects using HoloViews at `examples.pyviz.org <https://examples.pyviz.org>`_, and you can compare HoloViews to other available tools at `pyviz.org <https://pyviz.org>`_.

If you have any questions or usage issues visit the `HoloViews Discourse <https://discourse.holoviz.org/c/holoviews/>`_ site. If you are interested in contributing to HoloViews development to help address some of the `open issues <https://github.com/holoviz/holoviews/issues>`_, you can follow the `developer instructions for the Panel library <https://panel.holoviz.org/developer_guide/>`_ to set up your development environment.

If you like HoloViews and have built something you want to share, tweet a link or screenshot of your latest creation at @HoloViews, along with any other library you used (@HoloViz_org, @Panel_org, @Datashader, @BokehPlots, @Matplotlib, etc.). Thanks!

HoloViews is supported and maintained by `Anaconda <https://www.anaconda.com>`_.

Prior Funding
-------------

.. image:: http://www.anc.ed.ac.uk/anc.png
   :height: 60px
   :alt: ANC website
   :align: left
   :target: http://www.anc.ed.ac.uk

The original development of HoloViews was supported in part by Grants EP/F500385/1 and BB/F529254/1
to the `University of Edinburgh
Doctoral Training Centre in Neuroinformatics and Computational Neuroscience <http://www.anc.ed.ac.uk/dtc>`_
from the UK Engineering and Physical Sciences Research Council,
Biotechnology and Biological Sciences Research Council, and
Medical Research Council.
